==> haskell-stm-chans-3.0.0.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.6
visibility:           public
id:                   stm-chans-3.0.0.6-IkvKahCCN2PGmUmoXdymwY
key:                  stm-chans-3.0.0.6-IkvKahCCN2PGmUmoXdymwY
license:              BSD-3-Clause
copyright:            Copyright (c) 2011–2021 wren gayle romano
maintainer:           wren@cpan.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             https://wrengr.org/software/hackage.html
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  97f06fec2c4f74396af4da277d57b7a8
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-9.0.2/site-local/stm-chans-3.0.0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/stm-chans-3.0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/stm-chans-3.0.0.6
hs-libraries:         HSstm-chans-3.0.0.6-IkvKahCCN2PGmUmoXdymwY
depends:              base-4.15.1.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.9-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.9
visibility:           public
id:                   stm-chans-3.0.0.9-H1eecIu3XuZANDktrEikMK
key:                  stm-chans-3.0.0.9-H1eecIu3XuZANDktrEikMK
license:              BSD-3-Clause
copyright:            2011–2023 wren romano
maintainer:           wren@cpan.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             https://wrengr.org/software/hackage.html
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  299f90da020c660739e534469baf845a
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-9.0.2/site-local/stm-chans-3.0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/stm-chans-3.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-chans
hs-libraries:         HSstm-chans-3.0.0.9-H1eecIu3XuZANDktrEikMK
depends:              base-4.15.1.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
